@@ -84,6 +84,7 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "Escolha um ficheiro para adicionar como anexo",
     "Set up an account" : "Configurar uma conta",
     "Plain text" : "Texto simples",
+    "No messages" : "Sem mensagens",
     "Draft: " : "Rascunho:",
     "Unfavorite" : "Não favorito",
     "Favorite" : "Favorito",
@@ -178,6 +179,8 @@ OC.L10N.register(
     "Reservation {id}" : "Reserva {id}",
     "Train" : "Comboio",
     "Reset" : "Reiniciar",
+    "Client ID" : "Id. do Cliente",
+    "Client secret" : "Segredo do cliente\\\\",
     "Email: {email}" : "Email: {email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} em {host}:{port} ({ssl} encryption)",
     "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} em {host}:{port} ({ssl} encryption)",
@@ -187,6 +190,7 @@ OC.L10N.register(
     "Host" : "Anfitrião",
     "Port" : "Porta",
     "SMTP" : "SMTP",
+    "Account connected" : "Conta ligada",
     "Keyboard shortcut" : "Atalho de teclado",
     "Keyboard shortcuts" : "Atalhos de teclado",
     "Compose new message" : "Compor nova mensagem",
