@@ -19,12 +19,14 @@ OC.L10N.register(
     "Reply" : "جاۋاب قايتۇر",
     "Delete" : "ئۆچۈر",
     "Add" : "قوش",
+    "Tags" : "بەلگەلەر",
+    "Search" : "Search",
+    "Date" : "Date",
     "Remove" : "چىقىرىۋەت",
     "General" : "ئادەتتىكى",
     "User" : "User",
     "Host" : "باش ئاپپارات",
     "Port" : "ئېغىز",
-    "Search" : "Search",
     "Refresh" : "يېڭىلا",
     "All" : "ھەممىسى",
     "Favorites" : "يىغقۇچ"
